<?php

namespace Litecms\Rank\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Rank\Http\Requests\RankSettingRequest;
use Litecms\Rank\Interfaces\RankSettingRepositoryInterface;
use Litecms\Rank\Models\RankSetting;

/**
 * Resource controller class for rank_setting.
 */
class RankSettingResourceController extends BaseController
{

    /**
     * Initialize rank_setting resource controller.
     *
     * @param type RankSettingRepositoryInterface $rank_setting
     *
     * @return null
     */
    public function __construct(RankSettingRepositoryInterface $rank_setting)
    {
        parent::__construct();
        $this->repository = $rank_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Rank\Repositories\Criteria\RankSettingResourceCriteria::class);
    }

    /**
     * Display a list of rank_setting.
     *
     * @return Response
     */
    public function index(RankSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Rank\Repositories\Presenter\RankSettingPresenter::class)
                ->$function();
        }

        $rank_settings = $this->repository->paginate();

        return $this->response->title(trans('rank::rank_setting.names'))
            ->view('rank::rank_setting.index', true)
            ->data(compact('rank_settings'))
            ->output();
    }

    /**
     * Display rank_setting.
     *
     * @param Request $request
     * @param Model   $rank_setting
     *
     * @return Response
     */
    public function show(RankSettingRequest $request, RankSetting $rank_setting)
    {

        if ($rank_setting->exists) {
            $view = 'rank::rank_setting.show';
        } else {
            $view = 'rank::rank_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('rank::rank_setting.name'))
            ->data(compact('rank_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new rank_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(RankSettingRequest $request)
    {

        $rank_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('rank::rank_setting.name')) 
            ->view('rank::rank_setting.create', true) 
            ->data(compact('rank_setting'))
            ->output();
    }

    /**
     * Create new rank_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RankSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $rank_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('rank::rank_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('rank/rank_setting/' . $rank_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/rank/rank_setting'))
                ->redirect();
        }

    }

    /**
     * Show rank_setting for editing.
     *
     * @param Request $request
     * @param Model   $rank_setting
     *
     * @return Response
     */
    public function edit(RankSettingRequest $request, RankSetting $rank_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('rank::rank_setting.name'))
            ->view('rank::rank_setting.edit', true)
            ->data(compact('rank_setting'))
            ->output();
    }

    /**
     * Update the rank_setting.
     *
     * @param Request $request
     * @param Model   $rank_setting
     *
     * @return Response
     */
    public function update(RankSettingRequest $request, RankSetting $rank_setting)
    {
        try {
            $attributes = $request->all();

            $rank_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('rank::rank_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('rank/rank_setting/' . $rank_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('rank/rank_setting/' . $rank_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the rank_setting.
     *
     * @param Model   $rank_setting
     *
     * @return Response
     */
    public function destroy(RankSettingRequest $request, RankSetting $rank_setting)
    {
        try {

            $rank_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('rank::rank_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('rank/rank_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('rank/rank_setting/' . $rank_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple rank_setting.
     *
     * @param Model   $rank_setting
     *
     * @return Response
     */
    public function delete(RankSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('rank::rank_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('rank/rank_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/rank/rank_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted rank_settings.
     *
     * @param Model   $rank_setting
     *
     * @return Response
     */
    public function restore(RankSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('rank::rank_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/rank/rank_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/rank/rank_setting/'))
                ->redirect();
        }

    }

}
